@@ -84,7 +84,7 @@ void BssidComboBox::init(const QString & bssid, const QString &ssid)
 
     QList<NetworkManager::AccessPoint::Ptr> aps;
 
-    Q_FOREACH (const NetworkManager::Device::Ptr & device, NetworkManager::networkInterfaces()) {
+    for (const NetworkManager::Device::Ptr &device : NetworkManager::networkInterfaces()) {
         if (device->type() == NetworkManager::Device::Wifi) {
             NetworkManager::WirelessDevice::Ptr wifiDevice = device.objectCast<NetworkManager::WirelessDevice>();
             NetworkManager::WirelessNetwork::Ptr wifiNetwork = wifiDevice->findNetwork(ssid);
@@ -93,9 +93,9 @@ void BssidComboBox::init(const QString & bssid, const QString &ssid)
                 continue;
             }
 
-            Q_FOREACH (const NetworkManager::AccessPoint::Ptr & newAp, wifiNetwork->accessPoints()) {
+            for (const NetworkManager::AccessPoint::Ptr &newAp : wifiNetwork->accessPoints()) {
                 bool found = false;;
-                Q_FOREACH (const NetworkManager::AccessPoint::Ptr & existingAp, aps) {
+                for (const NetworkManager::AccessPoint::Ptr &existingAp : aps) {
                     if (newAp->hardwareAddress() == existingAp->hardwareAddress()) {
                         if (newAp->signalStrength() > existingAp->signalStrength()) {
                             aps.removeOne(existingAp);
@@ -136,7 +136,7 @@ void BssidComboBox::addBssidsToCombo(const QList<NetworkManager::AccessPoint::Pt
         return;
     }
 
-    Q_FOREACH (const NetworkManager::AccessPoint::Ptr & ap, aps) {
+    for (const NetworkManager::AccessPoint::Ptr &ap : aps) {
         if (!ap) {
             continue;
         }
