@@ -17,7 +17,6 @@
     You should have received a copy of the GNU Lesser General Public
     License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
-
 #include "networkmodelitem.h"
 #include "uiutils.h"
 
@@ -29,9 +28,7 @@
 #include <NetworkManagerQt/Manager>
 #include <NetworkManagerQt/ModemDevice>
 #include <NetworkManagerQt/Settings>
-#if NM_CHECK_VERSION (0, 9, 10)
 #include <NetworkManagerQt/TeamDevice>
-#endif
 #include <NetworkManagerQt/Utils>
 #include <NetworkManagerQt/VlanDevice>
 #include <NetworkManagerQt/VpnConnection>
@@ -207,6 +204,7 @@ QString NetworkModelItem::icon() const
         case NetworkManager::ConnectionSettings::Vlan:
             break;
         case NetworkManager::ConnectionSettings::Vpn:
+        case NetworkManager::ConnectionSettings::WireGuard:
             return QStringLiteral("network-vpn");
             break;
         case NetworkManager::ConnectionSettings::Wired:
@@ -251,12 +249,10 @@ NetworkModelItem::ItemType NetworkModelItem::itemType() const
         m_type == NetworkManager::ConnectionSettings::Bond ||
         m_type == NetworkManager::ConnectionSettings::Bridge ||
         m_type == NetworkManager::ConnectionSettings::Vlan ||
-#if NM_CHECK_VERSION(0, 9, 10)
         m_type == NetworkManager::ConnectionSettings::Team ||
-#endif
         ((NetworkManager::status() == NetworkManager::Connected ||
           NetworkManager::status() == NetworkManager::ConnectedLinkLocal ||
-          NetworkManager::status() == NetworkManager::ConnectedSiteOnly) && m_type == NetworkManager::ConnectionSettings::Vpn)) {
+          NetworkManager::status() == NetworkManager::ConnectedSiteOnly) && (m_type == NetworkManager::ConnectionSettings::Vpn || m_type == NetworkManager::ConnectionSettings::WireGuard))) {
         if (m_connectionPath.isEmpty() && m_type == NetworkManager::ConnectionSettings::Wireless) {
             return NetworkModelItem::AvailableAccessPoint;
         } else {
@@ -481,7 +477,6 @@ void NetworkModelItem::updateDetails() const
             }
         }
     }
-
     if (m_type == NetworkManager::ConnectionSettings::Wired) {
         NetworkManager::WiredDevice::Ptr wiredDevice = device.objectCast<NetworkManager::WiredDevice>();
         if (wiredDevice) {
@@ -585,7 +580,6 @@ void NetworkModelItem::updateDetails() const
     } else if (m_type == NetworkManager::ConnectionSettings::Adsl) {
         m_details << i18n("Type") << i18n("Adsl");
     }
-#if NM_CHECK_VERSION (0, 9, 10)
       else if (m_type == NetworkManager::ConnectionSettings::Team) {
         NetworkManager::TeamDevice::Ptr teamDevice = device.objectCast<NetworkManager::TeamDevice>();
         m_details << i18n("Type") << i18n("Team");
@@ -593,5 +587,4 @@ void NetworkModelItem::updateDetails() const
             m_details << i18n("MAC Address") << teamDevice->hwAddress();
         }
     }
-#endif
 }
